package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.HeHeUserDto;
import com.caimei365.user.model.vo.HeHeUserVo;
import com.caimei365.user.service.HeHeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;

/**
 * 呵呵商城用户API
 *
 * @author : plf
 * @date : 2021/4/21
 */
@Api(tags = "呵呵商城用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/he")
public class HeHeApi {

    private final HeHeService heHeService;

    @ApiOperation("微信授权登录")
    @GetMapping("/authorization")
    public ResponseJson<HeHeUserVo> authorization(String code, @RequestHeader HttpHeaders headers) {
        if (StringUtils.isBlank(code)) {
            return ResponseJson.error("微信code异常", null);
        }
        return heHeService.authorization(code, headers);
    }

    @ApiOperation("手机号验证码登录")
    @PostMapping("/mobile/login")
    public ResponseJson<HeHeUserVo> mobileLogin(HeHeUserDto heHeUserDto) {
        if (StringUtils.isBlank(heHeUserDto.getMobile())) {
            return ResponseJson.error("请输入手机号", null);
        }
        if (StringUtils.isBlank(heHeUserDto.getVerificationCode())) {
            return ResponseJson.error("请输入短信验证码", null);
        }
        if (StringUtils.isBlank(heHeUserDto.getOpenId()) || StringUtils.isBlank(heHeUserDto.getNickName()) || StringUtils.isBlank(heHeUserDto.getHeadImgUrl())) {
            return ResponseJson.error("微信信息异常", null);
        }
        return heHeService.mobileLogin(heHeUserDto);
    }

    @ApiOperation("发送手机号验证码")
    @GetMapping("/send")
    public ResponseJson<String> sendVerificationCode(String mobile) {
        if (StringUtils.isBlank(mobile)) {
            return ResponseJson.error("请输入手机号", null);
        }
        return heHeService.sendVerificationCode(mobile);
    }

    @ApiOperation("获取首页微信群二维码")
    @GetMapping("/group/qrCode")
    public ResponseJson<String> getGroupQrCode() {
        return heHeService.getGroupQrCode();
    }
}
