package com.caimei365.user.service;

import com.aliyuncs.exceptions.ClientException;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.MobileDto;
import com.caimei365.user.model.dto.PasswordDto;

import java.util.HashMap;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/4
 */
public interface BaseService {
    /**
     * 获取图片验证码
     *
     * @param platformType 0:www，1:crm/h5，2:小程序
     * @return Map<String, Object>
     */
    ResponseJson<Map<String, Object>> getCaptchaImage(Integer platformType);

    /**
     * 校验图片验证码
     *
     * @param token        图片验证码token
     * @param imgCode      图片验证码
     * @param platformType 0:www，1:crm/h5，2:小程序
     * @return Boolean
     */
    Boolean checkCaptchaImage(String token, String imgCode, Integer platformType);

    /**
     * 获取短信验证码
     *
     * @param mobile           手机号
     * @param activateCodeType 1:找回密码,2:手机号注册机构,3:供应商注册,4:修改手机号-旧手机验证码,5:修改手机号-新手机验证码
     * @param platformType     0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha   是否检查图片验证码，0:检查，1:不检查
     * @param imgCode          图片验证码
     * @param token            图片验证码token
     * @return void
     */
    ResponseJson getSmsCode(String mobile, Integer activateCodeType, Integer platformType, Integer isCheckCaptcha, String imgCode, String token);

    /**
     * 绑定账号,发送短信验证
     *
     * @param mobile         运营人员手机号
     * @param bindMobile     机构手机号
     * @param userId         机构Id
     * @param platformType   0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha 是否检查图片验证码，0:检查，1:不检查
     * @param imgCode        图片验证码
     * @param token          图片验证码token
     */
    ResponseJson getBindSmsCode(String mobile, String bindMobile, Integer userId, Integer platformType, Integer isCheckCaptcha, String imgCode, String token);

    /**
     * 获取邮箱验证码
     *
     * @param email  邮箱
     * @param status 1:绑定邮箱,2邮箱注册,3邮箱找回秘密
     */
    ResponseJson getEmailCode(String email, Integer status);

    /**
     * 修改密码（找回密码）
     *
     * @param passwordDto {
     *                    mobileOrEmail 手机号或邮箱
     *                    smsCode       短信验证码(旧：activationCode)
     *                    password      密码
     *                    confirmPwd    确认密码
     *                    status        1:手机号找回,2:邮箱找回
     *                    }
     */
    ResponseJson updatePassword(PasswordDto passwordDto);

    /**
     * 更换手机号
     *
     * @param mobileDto {
     *                  mobile          旧手机号(contractMobile)
     *                  smsCode         旧手机短信验证码(mobileCode)
     *                  newMobile       新手机号(contractMobile2)
     *                  newSmsCode      新手机短信验证码(mobileCode)
     *                  userId          用户Id
     *                  }
     */
    ResponseJson updateMobile(MobileDto mobileDto);

    ResponseJson findVipHistory(Integer userId, Integer pageNum, Integer pageSize);

    ResponseJson<Map<String, Object>> superCenter(Integer userId, Integer source);

    /**
     * 查超级会员套餐详情
     * @return
     */
    ResponseJson findPackage();

    ResponseJson<HashMap<String, String>> ossTokenGet() throws ClientException;
}
